
import { useState } from 'react';
import { useAuth } from '@/contexts/AuthContext';
import Logo from './navbar/Logo';
import UserMenu from './navbar/UserMenu';
import MainNav from './navbar/MainNav';
import ContactButton from './navbar/ContactButton';
import ContactDialog from './navbar/ContactDialog';
import AuthButtons from './navbar/AuthButtons';
import MobileMenu from './navbar/MobileMenu';

const Navbar = () => {
  const { isAuthenticated } = useAuth();
  const [contactDialogOpen, setContactDialogOpen] = useState(false);

  return (
    <header className="fixed top-0 left-0 right-0 navbar z-50 border-b">
      <div className="container mx-auto px-4 h-16 flex items-center justify-between">
        <div className="flex items-center space-x-8">
          <Logo />
          <MainNav isAuthenticated={isAuthenticated} />
        </div>
        
        <div className="flex items-center gap-4">
          <ContactButton onClick={() => setContactDialogOpen(true)} />
          
          {isAuthenticated ? (
            <UserMenu />
          ) : (
            <AuthButtons />
          )}

          <ContactDialog 
            open={contactDialogOpen} 
            onOpenChange={setContactDialogOpen} 
          />

          <MobileMenu />
        </div>
      </div>
    </header>
  );
};

export default Navbar;
